@@ -1,5 +1,3 @@
-/* $Id: main.c,v 1.1.1.1 2002/10/14 09:31:17 sch Exp $ */
-
 /*
  *    WMCPULoad - A dockapp to monitor CPU usage
  *    Copyright (C) 2001,2002  Seiichi SATO <ssato@sh.rim.or.jp>
@@ -37,11 +35,9 @@
 
 typedef enum { LIGHTON, LIGHTOFF } light;
 
-Pixmap pixmap;
 Pixmap backdrop_on;
 Pixmap backdrop_off;
 Pixmap parts;
-Pixmap pix_chartbuf;
 Pixmap mask;
 static char	*display_name = "";
 static char	*title = NULL;
@@ -55,10 +51,12 @@ static int	hindex = 0;
 
 /* prototypes */
 static void update(void);
+static void redraw(void);
 static void switch_light(void);
 static void draw_digit(int per);
 static void parse_arguments(int argc, char **argv);
 static void print_help(char *prog);
+Window dockapp_win(void);
 #if USE_SMP
 static void draw_cpunumber(void);
 #endif
@@ -73,14 +71,13 @@ main(int argc, char **argv)
     /* Parse Command-Line */
     cpu_opts.ignore_nice = False;
     cpu_opts.cpu_number = CPUNUM_NONE;
-    cpu_opts.ignore_procs = 0;
     parse_arguments(argc, argv);
 
     /* Initialize Application */
     cpu_init();
     dockapp_open_window(display_name, title == NULL ? PACKAGE : title,
 			SIZE, SIZE, argc, argv);
-    dockapp_set_eventmask(ButtonPressMask);
+    dockapp_set_eventmask(ButtonPressMask | ExposureMask);
 
     if (light_color) {
 	colors[0].pixel = dockapp_getcolor_pixel(light_color);
@@ -89,9 +86,8 @@ main(int argc, char **argv)
     }
 
     /* change raw xpm data to pixmap */
-    if (dockapp_stat == WINDOWED_WITH_PANEL) {
+    if (dockapp_stat == WINDOWED_WITH_PANEL)
 	backlight_on_xpm[1] = backlight_off_xpm[1] = WINDOWED_BG;
-    }
     dockapp_xpm2pixmap(backlight_on_xpm, &backdrop_on, &mask, colors, ncolor);
     dockapp_xpm2pixmap(backlight_off_xpm, &backdrop_off, NULL, NULL, 0);
     dockapp_xpm2pixmap(parts_xpm, &parts, NULL, colors, ncolor);
@@ -100,17 +96,13 @@ main(int argc, char **argv)
 	dockapp_setshape(mask, 0, 0);
     }
     if (mask) XFreePixmap(display, mask);
-    /* pixmap : draw area */
-    pixmap = dockapp_XCreatePixmap(SIZE, SIZE);
-    pix_chartbuf = dockapp_XCreatePixmap(SIZE, SIZE);
 
     /* Initialize pixmap */
     if (backlight == LIGHTON) {
-	dockapp_copyarea(backdrop_on, pixmap, 0, 0, SIZE, SIZE, 0, 0);
+	dockapp_set_background(backdrop_on);
     } else {
-	dockapp_copyarea(backdrop_off, pixmap, 0, 0, SIZE, SIZE, 0, 0);
+	dockapp_set_background(backdrop_off);
     }
-    dockapp_set_background(pixmap);
     dockapp_show();
 
     /* Main loop */
@@ -120,6 +112,10 @@ main(int argc, char **argv)
 	    switch(event.type) {
 		case ButtonPress:
 		    switch_light();
+		    redraw();
+		    break;
+		case Expose:
+		    redraw();
 		    break;
 		default: /* make gcc happy */
 		    break;
@@ -139,10 +135,19 @@ update(void)
 {
     int usage;
     int x, h;
+    Pixmap backdrop;
 
     static light pre_backlight;
     static Bool in_alarm_mode = False;
 
+    if (backlight == LIGHTON) {
+	backdrop = backdrop_on;
+	x = 2;
+    } else {
+	backdrop = backdrop_off;
+	x = 0;
+    }
+
     /* get current cpu usage in percent */
     usage = cpu_get_usage(&cpu_opts);
     hindex++;
@@ -159,6 +164,7 @@ update(void)
 	}
 	if (backlight == LIGHTOFF) {
 	    switch_light();
+	    redraw();
 	    return;
 	}
     } else {
@@ -166,22 +172,18 @@ update(void)
 	    in_alarm_mode = False;
 	    if (backlight != pre_backlight) {
 		switch_light();
+		redraw();
 		return;
 	    }
 	}
     }
 
-    /* save current chart */
-    dockapp_copyarea(pixmap, pix_chartbuf,  9, 33, 44, 21, 0, 0);
+    /* slide past chart */
+    dockapp_copyarea(dockapp_win(), dockapp_win(), 9, 33, 44, 21, 6, 33);
+    dockapp_copy2window(backdrop, 51, 33, 2, 21, 51, 33);
 
-    /* all clear */
-    if (backlight == LIGHTON) {
-	dockapp_copyarea(backdrop_on, pixmap, 0, 0, 58, 58, 0, 0);
-	x = 2;
-    } else {
-	dockapp_copyarea(backdrop_off, pixmap, 0, 0, 58, 58, 0, 0);
-	x = 0;
-    }
+    /* clear digit */
+    dockapp_copy2window(backdrop, 5, 7, 34, 20, 5, 7);
 
     /* draw digit */
     draw_digit(usage);
@@ -192,35 +194,41 @@ update(void)
 	draw_cpunumber();
 #endif
 
-    /* draw chart */
+    /* draw current chart */
     h = (21 * usage) / 100;
-    dockapp_copyarea(pix_chartbuf, pixmap, 0, 0, 44, 21, 6, 33);
-    dockapp_copyarea(parts, pixmap,100+x, 21-h, 2, h, 51, 54-h);
-
-    /* show */
-    dockapp_copy2window(pixmap);
-
+    dockapp_copy2window(parts, 100+x, 21-h, 2, h, 51, 54-h);
 }
 
 /* called when mouse button pressed */
 static void
 switch_light(void)
 {
-    int h, i, j = hindex;
-    int x = 0;
-
     switch (backlight) {
 	case LIGHTOFF:
 	    backlight = LIGHTON;
-	    dockapp_copyarea(backdrop_on, pixmap, 0, 0, 58, 58, 0, 0);
-	    x = 2;
 	    break;
 	case LIGHTON:
 	    backlight = LIGHTOFF;
-	    dockapp_copyarea(backdrop_off, pixmap, 0, 0, 58, 58, 0, 0);
-	    x = 0;
 	    break;
     }
+}
+
+static void
+redraw(void)
+{
+    int h, i, j = hindex;
+    int x = 0;
+    Pixmap backdrop;
+
+    if (backlight == LIGHTON) {
+	backdrop = backdrop_on;
+	x = 2;
+    } else {
+	backdrop = backdrop_off;
+	x = 0;
+    }
+
+    dockapp_copy2window(backdrop, 0, 0, 58, 58, 0, 0);
 
     /* redraw digit */
     draw_digit(history[hindex]);
@@ -234,13 +242,10 @@ switch_light(void)
     /* redraw chart */
     for (i = 0; i < MAX_HISTORY; i++) {
 	h = (21 * history[j]) / 100;
-	dockapp_copyarea(parts, pixmap, 100+x, 21-h, 2, h, 51-3*i, 54-h);
+	dockapp_copy2window(parts, 100+x, 21-h, 2, h, 51-3*i, 54-h);
 	j--;
 	if (j < 0) j = MAX_HISTORY - 1;
     }
-
-    /* show */
-    dockapp_copy2window(pixmap);
 }
 
 static void
@@ -261,15 +266,16 @@ draw_digit(int per)
     }
 
     /* draw digit */
-    dockapp_copyarea(parts, pixmap, v1 * 10, y, 10, 20, 29, 7);
+    dockapp_copy2window(parts, v1 * 10, y, 10, 20, 29, 7);
     if (v10 != 0) {
-	dockapp_copyarea(parts, pixmap, v10 * 10, y, 10, 20, 17, 7);
+	dockapp_copy2window(parts, v10 * 10, y, 10, 20, 17, 7);
     }
     if (v100 == 1) {
-	dockapp_copyarea(parts, pixmap, 10, y, 10, 20,  5, 7);
-	dockapp_copyarea(parts, pixmap,  0, y, 10, 20, 17, 7);
-	dockapp_copyarea(parts, pixmap,  0, y, 10, 20, 29, 7);
+	dockapp_copy2window(parts, 10, y, 10, 20,  5, 7);
+	dockapp_copy2window(parts,  0, y, 10, 20, 17, 7);
+	dockapp_copy2window(parts,  0, y, 10, 20, 29, 7);
     }
+
 }
 
 
@@ -277,20 +283,17 @@ draw_digit(int per)
 static void
 draw_cpunumber(void)
 {
-    int x_offset = 0;
-    int v10 = 0, v1 = 0;
+    int x, v1 = 0, v2 = 0;
 
-    v10 = cpu_opts.cpu_number / 10;
-    v1 = cpu_opts.cpu_number - v10 * 10;
+    v2 = cpu_opts.cpu_number / 10;
+    v1 = cpu_opts.cpu_number - v2 * 10;
 
-    if (backlight == LIGHTON) {
-	x_offset = 50;
-    }
+    x = backlight == LIGHTON ? 50 : 0;
 
-    if (v10) {
-	dockapp_copyarea(parts, pixmap, x_offset + v10 * 5, 40, 5, 9, 44, 10);
-    }
-    dockapp_copyarea(parts, pixmap, x_offset +  v1 * 5, 40, 5, 9, 50, 10);
+    if (v2)
+	dockapp_copy2window(parts, x + v2 * 5, 40, 5, 9, 44, 10);
+
+    dockapp_copy2window(parts, x +  v1 * 5, 40, 5, 9, 50, 10);
 }
 #endif
 
@@ -364,33 +367,6 @@ parse_arguments(int argc, char **argv)
 	    i++;
 	}
 
-#ifdef IGNORE_PROC
-	else if (!strcmp(argv[i], "--ignore-proc") || !strcmp(argv[i], "-p")) {
-	    if (argc == i + 1)
-		fprintf(stderr, "%s: error parsing argument for option %s\n",
-			argv[0], argv[i]), exit(1);
-	    if (argv[i + 1][0] == '-')
-		fprintf(stderr, "%s: error parsing argument for option %s\n",
-			argv[0], argv[i]), exit(1);
-	    while (i + 1 < argc) {
-		if (!(argv[i + 1][0] == '-')) {
-		    if (strlen(argv[i + 1]) >= COMM_LEN)
-			fprintf(stderr, "%s: command name %s is longer than 15 characters\n",
-				argv[0], argv[i + 1]), exit(1);
-		    if (cpu_opts.ignore_procs == MAX_PROC)
-			fprintf(stderr, "%s: maximum number of command names is %d\n",
-				argv[0], MAX_PROC), exit(1);
-		    cpu_opts.ignore_proc_list[cpu_opts.ignore_procs] = argv[i + 1];
-		    cpu_opts.ignore_procs++;
-		} else {
-		    break;
-		}
-		i++;
-	    }
-
-	}
-#endif	/* IGNORE_PROC */
-
 #ifdef USE_SMP
 	else if (!strcmp(argv[i], "--cpu") || !strcmp(argv[i], "-c")) {
 	    int integer;
@@ -414,13 +390,6 @@ parse_arguments(int argc, char **argv)
 	    print_help(argv[0]), exit(1);
 	}
     }
-
-#if defined(USE_SMP) && defined(IGNORE_PROC)
-    if (cpu_opts.cpu_number != CPUNUM_NONE && cpu_opts.ignore_procs) {
-	fprintf(stderr, "You can't use '-c, --cpu' option with '-p, --ignore_procs' option");
-	exit (1);
-    }
-#endif
 }
 
 static void
@@ -431,23 +400,29 @@ print_help(char *prog)
     printf("  -d,  --display <string>       display to use\n");
     printf("  -t,  --title <string>         application title name\n");
     printf("  -bl, --backlight              turn on back-light\n");
-    printf("  -lc, --light-color <string>   back-light color(rgb:6E/C6/3B is default)\n");
-    printf("  -i,  --interval <number>      number of secs between updates (1 is default)\n");
+    printf("  -lc, --light-color <string>   "
+	   "back-light color(rgb:6E/C6/3B is default)\n");
+    printf("  -i,  --interval <number>      "
+	   "number of secs between updates (1 is default)\n");
 #ifdef USE_SMP
-    printf("  -c,  --cpu <number>           which CPU is monitored (0, 1, ... )\n");
+    printf("  -c,  --cpu <number>           "
+	   "which CPU is monitored (0, 1, ... )\n");
 #endif
 #ifdef IGNORE_NICE
     printf("  -n,  --ignore-nice            ignore a nice value\n");
-#endif
-#ifdef IGNORE_PROC
-    printf("  -p,  --ignore-proc <name> ..  ignore all processes specified by command name\n");
 #endif
     printf("  -h,  --help                   show this help text and exit\n");
     printf("  -v,  --version                show program version and exit\n");
-    printf("  -w,  --windowed               run the application in windowed mode\n");
-    printf("  -wp, --windowed-withpanel     run the application in windowed mode\n");
+    printf("  -w,  --windowed               "
+	   "run the application in windowed mode\n");
+    printf("  -wp, --windowed-withpanel     "
+	   "run the application in windowed mode\n");
     printf("                                with background panel\n");
-    printf("  -bw, --broken-wm              activate broken window manager fix\n");
-    printf("  -a,  --alarm <percentage>     activate alarm mode. <percentage> is threshold\n");
-    printf("                                of percentage from 0 to 100.(90 is default)\n");
+    printf("  -bw, --broken-wm              "
+	   "activate broken window manager fix\n");
+    printf("  -a,  --alarm <percentage>     "
+	   "activate alarm mode. <percentage> is threshold\n");
+    printf("                                "
+	   "of percentage from 0 to 100.(90 is default)\n");
 }
+/* ex:set sw=4 softtabstop=4: */
